/******************************************************************************

Layered Windows example. Make window transparency using
SetLayeredWindowAttributes() (W2K only).

More info in MSDN:

MSDN Home > MSDN Library > User Interface Design and Development >
Windowing > Windows > About Windows > Window Types > Layered Windows

http://msdn.microsoft.com/library/default.asp?url=/library/en-us/winui/windows_3nar.asp

******************************************************************************/
#include <windows.h>
#include <windowsx.h>
#include <commctrl.h>
#include <string.h>
#include "layeredres.h"

/* Header fix for LCC */
#ifndef WS_EX_LAYERED
#define WS_EX_LAYERED           0x00080000
#endif

HWND hwndTrack;

/* prototype for the dialog box function. */
static BOOL CALLBACK DialogFunc(HWND hwndDlg, UINT msg, WPARAM wParam, LPARAM lParam);

int APIENTRY WinMain(HINSTANCE hinst, HINSTANCE hinstPrev, LPSTR lpCmdLine, int nCmdShow)
{
	WNDCLASS wc;

	memset(&wc,0,sizeof(wc));
	wc.lpfnWndProc = DefDlgProc;
	wc.cbWndExtra = DLGWINDOWEXTRA;
	wc.hInstance = hinst;
	wc.hCursor = LoadCursor(NULL, IDC_ARROW);
	wc.hbrBackground = (HBRUSH) (COLOR_WINDOW + 1);
	wc.lpszClassName = "layered";
	RegisterClass(&wc);

	InitCommonControls();

	return DialogBox(hinst, MAKEINTRESOURCE(IDD_MAINDIALOG), NULL, (DLGPROC) DialogFunc);

}

static int InitializeApp(HWND hDlg,WPARAM wParam, LPARAM lParam)
{
	LONG style;
	DWORD dwOK;

	/* To create a layered window, we must add WS_EX_LAYERED style. */
	style = GetWindowLong(hDlg, GWL_EXSTYLE);
	if(style == 0) return 0;
	style = style | WS_EX_LAYERED;
	if(0 == SetWindowLong(hDlg, GWL_EXSTYLE, style))
		return 0;

	// Set transparency level to "opaque"
	if(0 == SetLayeredWindowAttributes(hDlg, 0, 255, LWA_ALPHA))
		return 0;

	hwndTrack = GetDlgItem(hDlg, ID_TRACK);
	if(hwndTrack == NULL) return 0;

	SendMessage (hwndTrack, TBM_SETRANGE, TRUE, MAKELONG(0, 255));
	SendMessage (hwndTrack, TBM_SETPOS, TRUE, 255);

	return 1;
}

static BOOL CALLBACK DialogFunc(HWND hwndDlg, UINT msg, WPARAM wParam, LPARAM lParam)
{
	switch (msg) {
		case WM_INITDIALOG:
			if(0 == InitializeApp(hwndDlg,wParam,lParam))
				EndDialog(hwndDlg,0);
		return TRUE;

		case WM_NOTIFY:
		{
			INT pos;
			pos = SendMessage(hwndTrack, TBM_GETPOS, 0, 0);
			if(0 == SetLayeredWindowAttributes(hwndDlg, 0, pos, LWA_ALPHA))
				EndDialog(hwndDlg,0);
		}
		break;

		case WM_CLOSE:
			EndDialog(hwndDlg,0);
		return TRUE;

	}
	return FALSE;
}
